#!/bin/bash
#This script will help in setup kerberos 
#This script can be used for both ui as well as command line
. /opt/safesquid/safesquid_params.sh && EXPORT_INI

_KDESTROY=/usr/bin/kdestroy
_KINIT=/usr/bin/kinit
_MSKTUTIL=/usr/local/bin/msktutil

_AD_USER=""
MY_COMPUTER_NAME="$(hostname -s)"
MY_FQDN="$(hostname -f)"

LOG()
{
	echo -ne "kerberos : ${*}" 
}

KINIT_USER(){	
	
	${_KDESTROY} ; RET=$?	
	[ "x${RET}"  == "x1" ] && LOG "${_KDESTROY}: failed\n" 
	
	echo ${LDAP_PASSWORD} | ${_KINIT} --password-file=STDIN  ${_AD_USER} > /dev/null 2>&1
	RET=$?		
	[ "x${RET}" == "x1" ] && return 1;
	
	return 0 ;
}

RUN_MSKTUTIL(){
	#msktutil dependency-check.
	[ ! -f "${_MSKTUTIL}" ] && LOG "library: /usr/local/bin/msktutil: not found\n" && return 1;
    PAKG=$( ldd ${_MSKTUTIL} | grep "not found" )
    [ "x${PAKG}" != "x" ] && LOG "library:${PAKG}\n" && return 1
	
	${_MSKTUTIL} --verbose -c -b 'CN=COMPUTERS' -s HTTP/${MY_FQDN} -k ${KRB5_KTNAME} --computer-name ${MY_COMPUTER_NAME} --upn HTTP/${MY_FQDN} --server ${AD_FQDN} --no-reverse-lookups > /dev/null 2>&1
	
	RET=$?
	
	[ "x${RET}" == "x1" ] && return 1 ;
	return 0;
}

VAR_SETUP ()
{

	[ "x${KRB5_CONFIG}" == "x" ] && LOG "KRB5_CONFIG: not specified" && return 1;
	[ "x${KRB5_KTNAME}" == "x" ] && LOG "KRB5_KTNAME: not specified" && return 1;
	[ "x${AD_FQDN}" == "x" ] && LOG "AD_FQDN: not specified" && return 1;
	[ "x${LDAP_USER}" == "x" ] && LOG "LDAP_USER: not provided\n" && return 1;
	[ "x${LDAP_PASSWORD}" == "x" ] && LOG "LDAP_PASSWORD: not provided\n" && return 1;
	[ "x${AD_DOMAIN}" == "x" ] && LOG "AD_DOMAIN: not provided\n" && return 1;

	[ ! -f "${KRB5_CONFIG}" ] && LOG "KRB5_CONFIG: not found" && return 1;
	nslookup ${AD_FQDN} ; RET=$? 
	[ "x${RET}" == "x1" ] && LOG "nslookup: failed AD_FQDN: ${AD_FQDN}" && return 1
	
	_AD_USER="${LDAP_USER}@${AD_DOMAIN^^}"
	#MY_DOMAIN=`echo "${AD_DOMAIN}" | tr '[A-Z]' '[a-z]'`
	MY_DOMAIN=${AD_DOMAIN,,}
	MY_FQDN="${MY_COMPUTER_NAME}.${MY_DOMAIN}"
	
	nslookup ${MY_FQDN} ; RET=$? 
	[ "x${RET}" == "x1" ] && LOG "nslookup: failed MY_FQDN: ${MY_FQDN}" && return 1

#	ntpdate -p 1 -q ${AD_FQDN} ; ret=$?
	
}


MAIN(){	

	VAR_SETUP
	#should I deleted previously generated keytab?

	LOG "kinit user: _AD_USER: ${_AD_USER}\n"
	KINIT_USER
	RET=$?		

	if [ "x${RET}" == "x0" ]
	then	
		LOG "kinit: successful\n" 
	else			
		LOG "kinit: failed\n" 
		return 1 ; 
	fi
	
	LOG "Generate Keytab: calling RUN_MSKTUTIL\n"
	RUN_MSKTUTIL
	RET=$?	

	[ "x${RET}" == "x0" ] && LOG "Generate Keytab: successful\n" && return 1 ;
	LOG "Generate Keytab: failed\n" 
	
}

MAIN 
